@@ -1,6 +1,6 @@
 package Resque;
 # ABSTRACT: Redis-backed library for creating background jobs, placing them on multiple queues, and processing them later.
-$Resque::VERSION = '0.38';
+$Resque::VERSION = '0.39';
 use Moose;
 use Scalar::Util 'blessed';
 use Moose::Util::TypeConstraints;
@@ -76,6 +76,17 @@ sub pop {
     });
 }
 
+sub blpop {
+    my ( $self, $queues, $timeout ) = @_;
+    my ( $queue, $payload ) = $self->redis->blpop(( map { $self->key( queue => $_ ) } @$queues ), $timeout || 0 );
+    return unless $payload;
+
+    $self->new_job({
+        payload => $payload,
+        queue   => $queue
+    });
+}
+
 sub size {
     my ( $self, $queue ) = @_;
     $self->redis->llen( $self->key( queue => $queue ) );
@@ -190,7 +201,7 @@ Resque - Redis-backed library for creating background jobs, placing them on mult
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =head1 SYNOPSIS
 
@@ -301,6 +312,15 @@ Returns a Resque::Job object.
 
     my $resque_job = $r->pop( 'queue_name' );
 
+=head2 blpop
+
+Pops a job off an arrayref of queues prioritizing by order. Queue names should be string.
+It will block until a job is poped or the optional timeout in seconds.
+
+Returns a Resque::Job object.
+
+    my $resque_job = $r->blpop( [qw/ queue1 queue2 queue3/], 60 );
+
 =head2 size
 
 Returns the size of a queue.
